{% extends "admin/base_site.html" %}
{% load i18n admin_urls static %}

{% block extrahead %}
    {{ block.super }}
    {{ media }}
{% endblock %}


{% block bodyclass %}{{ block.super }} django-redis-data-manager-data-manager{% endblock %}


{% block breadcrumbs %}
<div class="breadcrumbs">
<a href="{% url 'admin:index' %}">{% trans 'Home' %}</a>
&rsaquo; <a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_config.verbose_name }}</a>
&rsaquo; <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
&rsaquo; {{ object|truncatewords:"18" }}
&rsaquo; {% trans 'Data Manager' %}
</div>
{% endblock %}


{% block content %}
<div class="django-redis-data-manager">
    <div class="django-redis-data-manager-toolbar">
        <span class="title">Redis实例—数据管理</span>
        <!-- <a href="#" class="button button-primary"><i class="fa fa-plus"></i>添加键</a>
        <a href="#" class="button button-primary"><i class="fa fa-edit"></i>修改值</a> -->
        <a href="#" class="button button-warning django-redis-data-manager-delete-button"><i class="fa fa-trash-alt"></i>删除当前键</a>
        <a href="#" class="button button-danger django-redis-data-manager-flushdb-button"><i class="fa fa-file"></i>清空缓存</a>
    </div>
    <div class="django-redis-data-manager-key-tree-wrapper">
        <div class="django-redis-data-manager-key-tree-inner">

            <div class="django-redis-data-manager-key-tree-header">{% trans "Redis Keys" %}</div>

            <div id="changelist">
            <div id="toolbar">
                <form class="django-redis-data-manager-key-search-form" method="get" action="">
                <div><!-- DIV needed for valid HTML -->
                <label for="django-redis-data-manager-key-tree-search-keyword"><img src="{% static "admin/img/search.svg" %}" alt="Search"></label>
                <input type="text" size="40" name="q" value="{{q}}" id="django-redis-data-manager-key-tree-search-keyword" />
                <input type="submit" value="{% trans "Search" %}" />
                <input type="submit" value="{% trans "Reet" %}" class="django-redis-data-manager-key-tree-search-reset" />
                </div>
                </form>
            </div></div>

            <div class="django-redis-data-manager-key-tree" django-redis-data-manager-config='{{config_json}}'></div>

        </div>
    </div>
    <div class="django-redis-data-manager-key-detail-outer">
        <div class="django-redis-data-manager-key-detail-inner">

            <div class="django-redis-data-manager-key-detail">
                <div class="django-redis-data-manager-key-detail-header">{% trans "Redis Key Detail" %}</div>
                <div class="django-redis-data-manager-key-detail-info"></div>
            </div>
        
        </div>
    </div>
</div>
{% endblock %}