from django.conf import settings


DJANGO_REDIS_DATA_MANAGER_REDIS_INSTANCE_CONNECTION_SAFE_FIELD_PASSWORD = getattr(settings, "DJANGO_REDIS_DATA_MANAGER_REDIS_INSTANCE_CONNECTION_SAFE_FIELD_PASSWORD", settings.SECRET_KEY)
DJANGO_REDIS_DATA_MANAGER_AUTO_REGISTER = getattr(settings, "DJANGO_REDIS_DATA_MANAGER_AUTO_REGISTER", True)
DJANGO_REDIS_DATA_MANAGER_APP_LABEL = getattr(settings, "DJANGO_REDIS_DATA_MANAGER_APP_LABEL", "django_redis_data_manager")
