.django-redis-data-manager-key-tree-wrapper {
    width: 40%;
    float: left;
}
.django-redis-data-manager-key-tree-inner {
    border: 1px solid #79aec8;
    width: 100%;
}
.django-redis-data-manager-key-detail-outer {
    margin-left: 40%;
}
.django-redis-data-manager-key-detail-inner {
    margin-left: 20px;
}
.django-redis-data-manager-key-detail {
    border: 1px solid #79aec8;
    width: 100%;
}
.django-redis-data-manager-key-tree {
    height: 500px;
    overflow: scroll;
}
.django-redis-data-manager-key-tree-header {
    height: 30px;
    line-height: 30px;
    background-color: #79aec8;
    color: #fff;
    padding-left: 10px;
    padding-right: 10px;
}
.django-redis-data-manager-key-tree-header i{
    width: 20px;
    height: 12px;
    color: #fff;
}
a.django-redis-data-manager-delete-selected-key{
    float: right;
    color: #fff;
}
.django-redis-data-manager-data-manager #changelist #toolbar {
    margin-bottom: 0;
}
.django-redis-data-manager-key-detail-header {
    height: 30px;
    line-height: 30px;
    background-color: #79aec8;
    color: #fff;
    padding: 0 10px;
}
.django-redis-data-manager-key-detail-info {
    height: 550px;
}
.django-redis-data-manager-key-detail-list{
    height: 394px;
    overflow: scroll;
}
.django-redis-data-manager-key-detail-info > span {
    width: 100%;
    height: 50px;
    line-height: 50px;
    text-align: center;
    display: block;
}
.django-redis-data-manager-key-detail-info table {
    width: 100%;
}
.django-redis-data-manager-toolbar {
    width: 100%;
    margin-bottom: 10px;
    text-align: right;
}
.django-redis-data-manager-toolbar .title {
    display: inline-block;
    height: 36px;
    line-height: 36px;
    font-size: 20px;
    font-weight: 300;
    color: #666;
    float: left;
}
.django-redis-data-manager-toolbar a.button {
    display: inline-block;
    height: 36px;
    line-height: 36px;
    padding: 0 10px;
    margin-left: 10px;
    background-color: #999;
    color: #fff;
}
.django-redis-data-manager-toolbar a.button-primary {
    background-color: #609ab6;
}
.django-redis-data-manager-toolbar a.button-warning {
    background-color: #f9801d;
}
.django-redis-data-manager-toolbar a.button-danger {
    background-color: #a41515;
}
.django-redis-data-manager-toolbar a.button:focus,
.django-redis-data-manager-toolbar a.button:visited {
    text-decoration: none;
}
.django-redis-data-manager-toolbar a.button i {
    padding-right: 8px;
}