<table>{% load i18n %}
    <tbody>
        <tr>
            <th width="100">{% trans "Key" %}</th>
            <td>{{key}}</td>
        </tr>
        <tr>
            <th>{% trans "Type" %}</th>
            <td>{% trans "Redis List" %}</td>
        </tr>
        <tr>
            <th>{% trans "LLen" %}</th>
            <td>{{value.llen}}</td>
        </tr>
        <tr>
            <th>{% trans "TTL" %}</th>
            <td>{{value_ttl}}</td>
        </tr>
    </tbody>
</table>
<table>
    <thead>
        <tr>
            <th width="100">{% trans "Index" %}</th>
            <th>{% trans "Item Value" %}</th>
        </tr>
    </thead>
</table>
<div class="django-redis-data-manager-key-detail-list">
<table>
    <tbody>
        {% for item in value.lrange %}
        <tr>
            <td width="100">{{forloop.counter}}</td>
            <td>{{item}}</td>
        </tr>
        {% endfor %}
    </tbody>
</table>
</div>