<table>{% load i18n %}
    <tbody>
        <tr>
            <th>{% trans "Key" %}</th>
            <td>{{key}}</td>
        </tr>
        <tr>
            <th>{% trans "Type" %}</th>
            <td>{% trans "Namespace" %}</td>
        </tr>
        <tr>
            <th>{% trans "Count" %}</th>
            <td>{{count}}</td>
        </tr>
    </tbody>
</table>