# Generated by Django 2.2.15 on 2020-09-23 09:52

from django.db import migrations, models
import django_safe_fields.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='RedisInstance',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=64, verbose_name='标题')),
                ('connection', django_safe_fields.fields.SafeCharField(max_length=4096, verbose_name='连接')),
                ('key_separator', models.CharField(default=':', max_length=16, verbose_name='分隔符')),
            ],
            options={
                'verbose_name': 'Redis实例',
                'verbose_name_plural': 'Redis实例',
            },
        ),
    ]
